import React from "react"
import type { HeadFC } from "gatsby"
import { graphql, useStaticQuery, } from "gatsby"
import { GatsbyImage, IGatsbyImageData, getImage, } from "gatsby-plugin-image"


type ImageNode = {
  node: {
    childImageSharp: {
      gatsbyImageData: IGatsbyImageData
    }
  }
}

type AllFileData = {
  allFile: {
    edges: ImageNode[]
  }
}


interface Product {
  id: string
  title: string
  description: string
  price: number
  stock: number,
  name: string,
  features: string,
  action: string;
}

interface Props {
  product: Product,
  data: AllFileData
}

export const getStaticProps = () => {
  return {
    props: {
      product: {
        id: 'lifestyle-705',
        title: "705 Lifestyle",
        price: 150,
        stock: 5,
        name: "705 Lifestyle",
        description: "Experience sophistication with the 705 Lifestyle. From timeless designs to cutting-edge innovations, explore curated fashion and lifestyle products that redefine elegance.",
        features: "Discover superior quality and unmatched style with the 705 Lifestyle Collection. Each item is a statement of refined taste and enduring elegance.",
        action: "Discover Now"
      },
    },
  }
}


function StaticPage() {
  const product = getStaticProps().props.product

  const data = useStaticQuery(graphql`
  query {
    allFile(filter: { extension: { eq: "jpg" } }) {
      edges {
        node {
          childImageSharp {
            gatsbyImageData(width: 320, height: 448, quality:100,transformOptions:{fit:COVER}) 
          }
        }
      }
    }
  }
`)
  return (
    <>
      <title>705 Lifestyle</title>
      <meta name="description" content="705 Lifestyle" />
      <meta name="keywords" content="brand, Vacuum flask, 705, bottle, t-shirt,hoodie,t-shirt pack, water, water bottle" />
      <meta name="author" content="Adylov Bekzot" />
      <div className="min-h-screen h- bg-black text-white  flex items-center justify-center">
        <div className="p-8  max-w-2xl text-center">
          <div className="mb-16 grid grid-cols-2 grid-rows-2 gap-4" >
            {data.allFile.edges.map((i: { node: { childImageSharp: { gatsbyImageData: IGatsbyImageData } } }, index: number) => (
              <div key={`container-${index}`}>
                <GatsbyImage
                  key={`img-${index}`}
                  image={getImage(i.node.childImageSharp.gatsbyImageData) as IGatsbyImageData}
                  alt={`Product ${index}`}
                />
                <h1 className="text-xl font-bold mt-2">${10 + index * 5}</h1>
              </div>
            ))}
          </div>
          <h1 className="text-3xl font-bold mb-2">{product.name}</h1>
          <p className="p-4 text-lg mb-4">{product.description}</p>
          {/* <Link to={"https://sevenzerofive.com/"}> */}
          <button className=" bg-white text-black py-2 px-4 rounded-md hover:bg-neutral-100 focus:outline-none focus:shadow-outline-green active:bg-neutral-200">
            {product.action}
          </button>
        </div>
      </div>
      <footer className="bg-black text-white py-4 pt-20 text-center">
        <p className="text-xs opacity-80">
          Disclaimer: This is a simulated showcase for demonstration purposes. Not an actual product page.
        </p>
      </footer>

    </>

  )
}



export default StaticPage